@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-view.c,v 1.62 2005/12/12 17:27:56 pborelli Exp $ 
+ * $Id: gedit-view.c,v 1.66 2006/01/30 09:17:51 pborelli Exp $ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,7 +49,7 @@
 #include "sexy-icon-entry.h"
 
 #define GEDIT_VIEW_SCROLL_MARGIN 0.02
-#define GEDIT_VIEW_SEARCH_DIALOG_TIMEOUT 5000
+#define GEDIT_VIEW_SEARCH_DIALOG_TIMEOUT (30*1000) /* 30 seconds */
 
 #define MIN_SEARCH_COMPLETION_KEY_LEN	3
 
@@ -100,10 +100,24 @@ static void	gedit_view_move_cursor		(GtkTextView     *text_view,
 						 GtkMovementStep  step,
 						 gint             count,
 						 gboolean         extend_selection);
+static gint     gedit_view_focus_out		(GtkWidget       *widget,
+						 GdkEventFocus   *event);
 
 static gboolean start_interactive_search	(GeditView       *view);
 static gboolean start_interactive_goto_line	(GeditView       *view);
+static gboolean reset_searched_text		(GeditView       *view);
 
+static void	hide_search_window 		(GeditView       *view,
+						 gboolean         cancel);
+
+
+static gint	gedit_view_expose	 	(GtkWidget       *widget,
+						 GdkEventExpose  *event);
+static void 	search_highlight_updated_cb	(GeditDocument   *doc,
+						 GtkTextIter     *start,
+						 GtkTextIter     *end,
+						 GeditView       *view);
+						 
 G_DEFINE_TYPE(GeditView, gedit_view, GTK_TYPE_SOURCE_VIEW)
 
 /* Signals */
@@ -111,6 +125,7 @@ enum
 {
 	START_INTERACTIVE_SEARCH,
 	START_INTERACTIVE_GOTO_LINE,
+	RESET_SEARCHED_TEXT,
 	LAST_SIGNAL
 };
 
@@ -139,13 +154,18 @@ gedit_view_class_init (GeditViewClass *klass)
 	GObjectClass     *object_class = G_OBJECT_CLASS (klass);
 	GtkObjectClass   *gtkobject_class = GTK_OBJECT_CLASS (klass);
 	GtkTextViewClass *textview_class = GTK_TEXT_VIEW_CLASS (klass);
+	GtkWidgetClass   *widget_class = GTK_WIDGET_CLASS (klass);
 	GtkBindingSet    *binding_set;
 
 	gtkobject_class->destroy = gedit_view_destroy;
 	object_class->finalize = gedit_view_finalize;
 
+	widget_class->focus_out_event = gedit_view_focus_out;
+	widget_class->expose_event = gedit_view_expose;
+
 	klass->start_interactive_search = start_interactive_search;
 	klass->start_interactive_goto_line = start_interactive_goto_line;
+	klass->reset_searched_text = reset_searched_text;	
 	textview_class->move_cursor = gedit_view_move_cursor;
 
 	view_signals[START_INTERACTIVE_SEARCH] =
@@ -164,17 +184,30 @@ gedit_view_class_init (GeditViewClass *klass)
 		  	      G_STRUCT_OFFSET (GeditViewClass, start_interactive_goto_line),
 			      NULL, NULL,
 			      gedit_marshal_BOOLEAN__NONE,
-			      G_TYPE_BOOLEAN, 0);	
+			      G_TYPE_BOOLEAN, 0);
+
+	view_signals[RESET_SEARCHED_TEXT] =
+    		g_signal_new ("reset_searched_text",
+		  	      G_TYPE_FROM_CLASS (object_class),
+		  	      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+		  	      G_STRUCT_OFFSET (GeditViewClass, reset_searched_text),
+			      NULL, NULL,
+			      gedit_marshal_BOOLEAN__NONE,
+			      G_TYPE_BOOLEAN, 0);		
 
 	g_type_class_add_private (klass, sizeof (GeditViewPrivate));
 	
 	binding_set = gtk_binding_set_by_class (klass);
 	
 	gtk_binding_entry_add_signal (binding_set, GDK_k, GDK_CONTROL_MASK, "start_interactive_search", 0);
-	gtk_binding_entry_add_signal (binding_set, GDK_K, GDK_CONTROL_MASK, "start_interactive_search", 0);	
+	gtk_binding_entry_add_signal (binding_set, GDK_K, GDK_CONTROL_MASK, "start_interactive_search", 0);
 	
 	gtk_binding_entry_add_signal (binding_set, GDK_i, GDK_CONTROL_MASK, "start_interactive_goto_line", 0);
-	gtk_binding_entry_add_signal (binding_set, GDK_I, GDK_CONTROL_MASK, "start_interactive_goto_line", 0);	
+	gtk_binding_entry_add_signal (binding_set, GDK_I, GDK_CONTROL_MASK, "start_interactive_goto_line", 0);
+	
+	gtk_binding_entry_add_signal (binding_set, GDK_k, GDK_CONTROL_MASK | GDK_SHIFT_MASK, "reset_searched_text", 0);
+	gtk_binding_entry_add_signal (binding_set, GDK_K, GDK_CONTROL_MASK | GDK_SHIFT_MASK, "reset_searched_text", 0);	
+
 }
 
 static void
@@ -391,6 +424,23 @@ gedit_view_finalize (GObject *object)
 	(* G_OBJECT_CLASS (gedit_view_parent_class)->finalize) (object);
 }
 
+static gint
+gedit_view_focus_out (GtkWidget *widget, GdkEventFocus *event)
+{
+	GeditView *view = GEDIT_VIEW (widget);
+	
+	gtk_widget_queue_draw (widget);
+	
+	/* hide interactive search dialog */
+	if (view->priv->search_window != NULL)
+		hide_search_window (view, FALSE);
+	
+	(* GTK_WIDGET_CLASS (gedit_view_parent_class)->focus_out_event) (widget, event);
+	
+	return FALSE;
+}
+
+
 /**
  * gedit_view_new:
  * @doc: a #GeditDocument
@@ -422,6 +472,11 @@ gedit_view_new (GeditDocument *doc)
 	gtk_text_view_set_editable (GTK_TEXT_VIEW (view), 
 				    !gedit_document_get_readonly (doc));					  
 
+	g_signal_connect (doc,
+			  "search_highlight_updated",
+			  G_CALLBACK (search_highlight_updated_cb),
+			  view);
+
 	gedit_debug_message (DEBUG_VIEW, "END: %d", G_OBJECT (view)->ref_count);
 
 	gtk_widget_show_all (view);
@@ -987,6 +1042,7 @@ hide_search_window (GeditView *view, gboolean cancel)
 
 	/* send focus-in event */
 	send_focus_change (GTK_WIDGET (view->priv->search_entry), FALSE);
+	gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (view), TRUE);
 	gtk_widget_hide (view->priv->search_window);
 	
 	if (cancel)
@@ -1006,7 +1062,7 @@ search_entry_flush_timeout (GeditView *view)
 	GDK_THREADS_ENTER ();
 
   	view->priv->typeselect_flush_timeout = 0;
-	hide_search_window (view, TRUE);
+	hide_search_window (view, FALSE);
 
 	GDK_THREADS_LEAVE ();
 
@@ -1035,7 +1091,7 @@ search_window_delete_event (GtkWidget   *widget,
 			    GdkEventAny *event,
 			    GeditView   *view)
 {
-	hide_search_window (view, TRUE);
+	hide_search_window (view, FALSE);
 
 	return TRUE;
 }
@@ -1045,7 +1101,7 @@ search_window_button_press_event (GtkWidget      *widget,
 				  GdkEventButton *event,
 				  GeditView      *view)
 {
-	hide_search_window (view, TRUE);
+	hide_search_window (view, FALSE);
 	
 	gtk_propagate_event (GTK_WIDGET (view), (GdkEvent *)event);
 
@@ -1114,9 +1170,15 @@ search_window_key_press_event (GtkWidget   *widget,
 {
 	gboolean retval = FALSE;
 
-	/* close window and cancel the search */
-	if (event->keyval == GDK_Escape ||
-	    event->keyval == GDK_Tab)
+	/* Close window */
+	if (event->keyval == GDK_Tab)
+	{
+		hide_search_window (view, FALSE);
+		retval = TRUE;
+	}
+	
+	/* Close window and cancel the search */
+	if (event->keyval == GDK_Escape)
 	{
 		if (view->priv->search_mode == SEARCH)
 		{
@@ -1656,16 +1718,16 @@ start_interactive_search_real (GeditView *view)
 		return FALSE;
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-	
+
 	if (view->priv->search_mode == SEARCH)
 		gtk_text_buffer_get_selection_bounds (buffer, &view->priv->start_search_iter, NULL);
 	else
 		gtk_text_buffer_get_iter_at_mark (buffer,
 						  &view->priv->start_search_iter,
 						  gtk_text_buffer_get_insert (buffer));
-					  		
+
 	ensure_search_window (view);
-		
+
 	/* done, show it */
 	update_search_window_position (view);
 	gtk_widget_show (view->priv->search_window);
@@ -1673,18 +1735,20 @@ start_interactive_search_real (GeditView *view)
 	if (view->priv->search_entry_changed_id == 0)
 	{
       		view->priv->search_entry_changed_id =
-			g_signal_connect (view->priv->search_entry, "changed",
+			g_signal_connect (view->priv->search_entry,
+					  "changed",
 					  G_CALLBACK (search_init),
 					  view);
 	}
-	
+
 	init_search_entry (view);
 
 	view->priv->typeselect_flush_timeout =  
 		g_timeout_add (GEDIT_VIEW_SEARCH_DIALOG_TIMEOUT,
 		   	       (GSourceFunc) search_entry_flush_timeout,
 		   	       view);
-		   
+
+	gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (view), FALSE);
 	gtk_widget_grab_focus (view->priv->search_entry);
 	
 	send_focus_change (view->priv->search_entry, TRUE);
@@ -1692,6 +1756,19 @@ start_interactive_search_real (GeditView *view)
 	return TRUE;
 }
 
+static gboolean
+reset_searched_text (GeditView *view)
+{		
+	GeditDocument *doc;
+
+	g_print ("Reset!");		
+	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
+	
+	gedit_document_set_search_text (doc, "", GEDIT_SEARCH_DONT_SET_FLAGS);
+	
+	return TRUE;
+}
+
 static gboolean
 start_interactive_search (GeditView *view)
 {		
@@ -1707,3 +1784,89 @@ start_interactive_goto_line (GeditView *view)
 	
 	return start_interactive_search_real (view);
 }
+
+static gint
+gedit_view_expose (GtkWidget      *widget,
+                   GdkEventExpose *event)
+{
+	GtkTextView *text_view;
+	GeditDocument *doc;
+	
+	text_view = GTK_TEXT_VIEW (widget);
+	
+	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (text_view));
+	
+	if ((event->window == gtk_text_view_get_window (text_view, GTK_TEXT_WINDOW_TEXT)) &&
+	    gedit_document_get_enable_search_highlighting (doc))
+	{
+		GdkRectangle visible_rect;
+		GtkTextIter iter1, iter2;
+		
+		gtk_text_view_get_visible_rect (text_view, &visible_rect);
+		gtk_text_view_get_line_at_y (text_view, &iter1,
+					     visible_rect.y, NULL);
+		gtk_text_view_get_line_at_y (text_view, &iter2,
+					     visible_rect.y
+					     + visible_rect.height, NULL);
+		gtk_text_iter_forward_line (&iter2);
+				     
+		_gedit_document_search_region (doc,
+					       &iter1,
+					       &iter2);
+	}
+
+	return (* GTK_WIDGET_CLASS (gedit_view_parent_class)->expose_event)(widget, event);
+}
+
+static void 	
+search_highlight_updated_cb (GeditDocument *doc,
+			     GtkTextIter   *start,
+			     GtkTextIter   *end,
+			     GeditView     *view)
+{
+	GdkRectangle visible_rect;
+	GdkRectangle updated_rect;	
+	GdkRectangle redraw_rect;
+	gint y;
+	gint height;
+	GtkTextView *text_view;
+	
+	text_view = GTK_TEXT_VIEW (view);
+
+	g_return_if_fail (gedit_document_get_enable_search_highlighting (
+				GEDIT_DOCUMENT (gtk_text_view_get_buffer (text_view))));
+	
+	/* get visible area */
+	gtk_text_view_get_visible_rect (text_view, &visible_rect);
+	
+	/* get updated rectangle */
+	gtk_text_view_get_line_yrange (text_view, start, &y, &height);
+	updated_rect.y = y;
+	gtk_text_view_get_line_yrange (text_view, end, &y, &height);
+	updated_rect.height = y + height - updated_rect.y;
+	updated_rect.x = visible_rect.x;
+	updated_rect.width = visible_rect.width;
+
+	/* intersect both rectangles to see whether we need to queue a redraw */
+	if (gdk_rectangle_intersect (&updated_rect, &visible_rect, &redraw_rect)) 
+	{
+		GdkRectangle widget_rect;
+		
+		gtk_text_view_buffer_to_window_coords (text_view,
+						       GTK_TEXT_WINDOW_WIDGET,
+						       redraw_rect.x,
+						       redraw_rect.y,
+						       &widget_rect.x,
+						       &widget_rect.y);
+		
+		widget_rect.width = redraw_rect.width;
+		widget_rect.height = redraw_rect.height;
+		
+		gtk_widget_queue_draw_area (GTK_WIDGET (text_view),
+					    widget_rect.x,
+					    widget_rect.y,
+					    widget_rect.width,
+					    widget_rect.height);
+	}
+}
+
